#!/usr/bin/env python
# -*- coding:utf-8 -*-
import random, string
from test_script import *
from lcyframe.libs import cprint, utils


def post_demo(*args, **kwargs):
    """
    添加:测试post
    
    参数:
    - str # 选填，,string,描述
    - str # 选填，,string,手机号
    - int # 必填, ,integer,整形
    - float # 必填, ,float,浮点型
    - json # 必填, ,json,json格式
    - form-data # 选填，,json,位置：body_json，参数放在body内，以multipart/form-data方式，json格式。json类型的参数，设为非必须时，需提供默认值
    - form-data2 # 选填，,string,位置：body_json，参数放在body内，以multipart/form-data方式，json格式。json类型的参数，设为非必须时，需提供默认值
    - www-form # 选填，,string,位置：body_form，参数放在body表单内，以multipart/x-www-form-urlencoded方式提交。手机号正则限定
    - excel # 选填，,file,上传文件，参数放在body内，以multipart/form-data方式提交;excel=self.params["excel"]
    """
    headers = {}
    files = {}
    # 上传文件，参数放在body内，以multipart/form-data方式提交;excel=self.params["excel"]
    files["excel"] = open("../请指定文件路径")
    
    params = {
        "str": "(选填)描述",
        "str": "(选填)手机号",
        "int": "(必填)整形",
        "float": "(必填)浮点型",
        "json": "(必填)json格式",
        "form-data": "(选填)位置：body_json，参数放在body内，以multipart/form-data方式，json格式。json类型的参数，设为非必须时，需提供默认值",
        "form-data2": "(选填)位置：body_json，参数放在body内，以multipart/form-data方式，json格式。json类型的参数，设为非必须时，需提供默认值",
        "www-form": "(选填)位置：body_form，参数放在body表单内，以multipart/x-www-form-urlencoded方式提交。手机号正则限定",
        }
    return send(methed="post", url="/demo", params=params, headers=headers, files=files)

def get_demo(*args, **kwargs):
    """
    查看:测试get
    
    参数:
    - _id # 选填，,str,id
    - a # 必填, ,integer,角色id
    - b # 选填，,string,供应商id
    - d # 选填，,int,城市全拼列表
    """
    headers = {"token": "1111"}
    files = {}
    params = {
        # "_id": "(选填)id",
        "a": 1,
        # "b": "(选填)供应商id",
        # "d": "(选填)城市全拼列表",
        }
    return send(methed="get", url="/demo", params=params, headers=headers, files=files)


def get_demo_list(*args, **kwargs):
    """
    列表:
    
    参数:
    - page # 选填，,integer,翻页码
    - count # 选填，,integer,每页显示条数
    - search # 选填，,str,搜索关键字
    - search # 选填，,str,搜索关键字
    - state # 选填，,int,申请状态
    - time_range # 选填，,str,申请时间范围，逗号隔开。2020-12-12 12:12:12,2022-12-12 12:12:12
    """
    headers = {}
    files = {}
    params = {
        "page": "(选填)翻页码",
        "count": "(选填)每页显示条数",
        "search": "(选填)搜索关键字",
        "search": "(选填)搜索关键字",
        "state": "(选填)申请状态",
        "time_range": "(选填)申请时间范围，逗号隔开。2020-12-12 12:12:12,2022-12-12 12:12:12",
        }
    return send(methed="get", url="/demo/list", params=params, headers=headers, files=files)


if __name__ == "__main__":
    # 添加
    # post_demo()
    # 查看
    get_demo()
    # 列表
    # get_demo_list()
    


#!/usr/bin/env python
# -*- coding:utf-8 -*-
import random, string
from test_script import *
from lcyframe.libs import cprint, utils


def get_admin_member(*args, **kwargs):
    """
    无说明:
    
    参数:
    - uid # 必填, ,int,uid
    """
    headers = {}
    files = {}
    params = {
        "uid": "(必填)uid",
        }
    return send(methed="get", url="/admin/member", params=params, headers=headers, files=files)

def post_admin_member(*args, **kwargs):
    """
    无说明:
    
    参数:
    - user_name # 必填, ,str,
    - pass_word # 必填, ,str,无说明，无说明
    - nick_name # 必填, ,str,
    - sex # 必填, ,int,1 无说明 0 无说明
    - mobile # 必填, ,str,无说明
    - email # 必填, ,str,无说明
    - gid # 必填, ,int,无说明 1 无说明 2 无说明
    """
    headers = {}
    files = {}
    params = {
        "user_name": "(必填)无描述",
        "pass_word": "(必填)无说明，无说明",
        "nick_name": "(必填)无描述",
        "sex": "(必填)1 无说明 0 无说明",
        "mobile": "(必填)无说明",
        "email": "(必填)无说明",
        "gid": "(必填)无说明 1 无说明 2 无说明",
        }
    return send(methed="post", url="/admin/member", params=params, headers=headers, files=files)

def put_admin_member(*args, **kwargs):
    """
    无说明:
    
    参数:
    - uid # 必填, ,int,
    - nick_name # 选填，,str,
    - sex # 选填，,int,1 无说明 0 无说明
    - mobile # 选填，,str,无说明
    - email # 选填，,str,无说明
    - gid # 选填，,int,无说明 1 无说明 2 无说明
    """
    headers = {}
    files = {}
    params = {
        "uid": "(必填)无描述",
        "nick_name": "(选填)无描述",
        "sex": "(选填)1 无说明 0 无说明",
        "mobile": "(选填)无说明",
        "email": "(选填)无说明",
        "gid": "(选填)无说明 1 无说明 2 无说明",
        }
    return send(methed="put", url="/admin/member", params=params, headers=headers, files=files)

def delete_admin_member(*args, **kwargs):
    """
    无说明:
    
    参数:
    - uid # 选填，,int,uid
    """
    headers = {}
    files = {}
    params = {
        "uid": "(选填)uid",
        }
    return send(methed="delete", url="/admin/member", params=params, headers=headers, files=files)


def post_admin_login(*args, **kwargs):
    """
    登录:
    
    参数:
    - user_name # 必填, ,str,用户名
    - pass_word # 必填, ,str,密码
    """
    headers = {}
    files = {}
    params = {
        "user_name": "(必填)用户名",
        "pass_word": "(必填)密码",
        }
    return send(methed="post", url="/admin/login", params=params, headers=headers, files=files)


def post_admin_resetpwd(*args, **kwargs):
    """
    忘记密码:
    
    参数:
    - pass_word # 必填, ,str,旧密码
    - 新密码 # 必填, ,str,无说明
    """
    headers = {}
    files = {}
    params = {
        "pass_word": "(必填)旧密码",
        "新密码": "(必填)无说明",
        }
    return send(methed="post", url="/admin/resetpwd", params=params, headers=headers, files=files)


def post_admin_find(*args, **kwargs):
    """
    无说明:无说明（无说明）
    
    参数:
    - page # 必填, ,str,无说明
    """
    headers = {}
    files = {}
    params = {
        "page": "(必填)无说明",
        }
    return send(methed="post", url="/admin/find", params=params, headers=headers, files=files)

def get_admin_find(*args, **kwargs):
    """
    无说明:无说明
    """
    headers = {}
    files = {}
    params = {
        }
    return send(methed="get", url="/admin/find", params=params, headers=headers, files=files)


if __name__ == "__main__":
    # 无说明
    get_admin_member()
    # 无说明
    post_admin_member()
    # 无说明
    put_admin_member()
    # 无说明
    delete_admin_member()
    # 登录
    post_admin_login()
    # 忘记密码
    post_admin_resetpwd()
    # 无说明
    post_admin_find()
    # 无说明
    get_admin_find()
    


#!/usr/bin/env python
# -*- coding:utf-8 -*-
import random, string
from test_script import *
from lcyframe.libs import cprint, utils


def post_user(*args, **kwargs):
    """
    添加:测试post
    
    参数:
    - a # 必填, ,integer,角色id
    - b # 选填，,string,供应商id
    - c # 选填，,string,手机号
    - d # 选填，,int,城市全拼列表
    - pic # 选填，,file,文件
    """
    headers = {}
    files = {}
    # 文件
    files["pic"] = open("../请指定文件路径")
    
    params = {
        "a": "(必填)角色id",
        "b": "(选填)供应商id",
        "c": "(选填)手机号",
        "d": "(选填)城市全拼列表",
        }
    return send(methed="post", url="/user", params=params, headers=headers, files=files)

def get_user(*args, **kwargs):
    """
    查看:测试get
    
    参数:
    - a # 必填, ,integer,角色id
    - b # 选填，,string,供应商id
    - d # 选填，,int,城市全拼列表
    """
    headers = {}
    files = {}
    params = {
        "a": "(必填)角色id",
        "b": "(选填)供应商id",
        "d": "(选填)城市全拼列表",
        }
    return send(methed="get", url="/user", params=params, headers=headers, files=files)


def post_user_list(*args, **kwargs):
    """
    添加:测试post
    
    参数:
    - a # 必填, ,integer,角色id
    - b # 选填，,string,供应商id
    - c # 选填，,string,手机号
    - d # 选填，,int,城市全拼列表
    - pic # 选填，,file,文件
    """
    headers = {}
    files = {}
    # 文件
    files["pic"] = open("../请指定文件路径")
    
    params = {
        "a": "(必填)角色id",
        "b": "(选填)供应商id",
        "c": "(选填)手机号",
        "d": "(选填)城市全拼列表",
        }
    return send(methed="post", url="/user_list", params=params, headers=headers, files=files)

def get_user_list(*args, **kwargs):
    """
    查看:测试get
    
    参数:
    - a # 必填, ,integer,角色id
    - b # 选填，,string,供应商id
    - d # 选填，,int,城市全拼列表
    """
    headers = {}
    files = {}
    params = {
        "a": "(必填)角色id",
        "b": "(选填)供应商id",
        "d": "(选填)城市全拼列表",
        }
    return send(methed="get", url="/user_list", params=params, headers=headers, files=files)


if __name__ == "__main__":
    # 添加
    post_user()
    # 查看
    get_user()
    # 添加
    post_user_list()
    # 查看
    get_user_list()
    


#!/usr/bin/env python
# -*- coding:utf-8 -*-
import random, string
from test_script import *
from lcyframe.libs import cprint, utils


def get_websocket(*args, **kwargs):
    """
    websocket链接测试:
    
    参数:
    - nickname # 选填，,string,用户昵称
    """
    headers = {}
    files = {}
    params = {
        "nickname": "(选填)用户昵称",
        }
    return send(methed="get", url="/websocket", params=params, headers=headers, files=files)


if __name__ == "__main__":
    # websocket链接测试
    get_websocket()
    


#!/usr/bin/env python
# -*- coding:utf-8 -*-
import random, string
from test_script import *
from lcyframe.libs import cprint, utils


def post_authorization(*args, **kwargs):
    """
    签发授权:授权开通使用某个服务、套餐。开通后，分自动激活和客户邮件连接激活
    
    参数:
    - company_id # 必填, ,int,客户id
    - product_id # 必填, ,int,产品id
    - service_life # 必填, ,int,授权时长，即产品有效期，单位天
    - domain_name_list # 必填, ,json,授权主域列表
    - active_mode # 必填, ,int,激活方式, 0直接激活，1邮件激活
    - email # 选填，,str,授权邮箱
    """
    headers = {}
    files = {}
    params = {
        "company_id": "(必填)客户id",
        "product_id": "(必填)产品id",
        "service_life": "(必填)授权时长，即产品有效期，单位天",
        "domain_name_list": "(必填)授权主域列表",
        "active_mode": "(必填)激活方式, 0直接激活，1邮件激活",
        "email": "(选填)授权邮箱",
        }
    return send(methed="post", url="/authorization", params=params, headers=headers, files=files)

def get_authorization(*args, **kwargs):
    """
    详情:
    
    参数:
    - id # 必填, ,int,id
    """
    headers = {}
    files = {}
    params = {
        "id": "(必填)id",
        }
    return send(methed="get", url="/authorization", params=params, headers=headers, files=files)

def put_authorization(*args, **kwargs):
    """
    编辑:
    
    参数:
    - id # 必填, ,int,记录id
    - service_list # 选填，,json,服务条目
    - domain_name_list # 选填，,json,授权域名
    - service_end # 选填，,datetime,到期时间
    """
    headers = {}
    files = {}
    params = {
        "id": "(必填)记录id",
        "service_list": "(选填)服务条目",
        "domain_name_list": "(选填)授权域名",
        "service_end": "(选填)到期时间",
        }
    return send(methed="put", url="/authorization", params=params, headers=headers, files=files)

def delete_authorization(*args, **kwargs):
    """
    删除:删除记录
    
    参数:
    - id # 必填, ,int,记录id
    """
    headers = {}
    files = {}
    params = {
        "id": "(必填)记录id",
        }
    return send(methed="delete", url="/authorization", params=params, headers=headers, files=files)


def get_authorization_list(*args, **kwargs):
    """
    授权列表:
    
    参数:
    - page # 选填，,integer,翻页码
    - count # 选填，,integer,每页显示条数
    - auth_state # 选填，,int,授权状态：0待激活，1已激活，2已过期
    - search # 选填，,str,搜索授权客户名称或产品名称等关键字查询
    - order_key # 选填，,str,排序字段,service_end=-1
    """
    headers = {}
    files = {}
    params = {
        "page": "(选填)翻页码",
        "count": "(选填)每页显示条数",
        "auth_state": "(选填)授权状态：0待激活，1已激活，2已过期",
        "search": "(选填)搜索授权客户名称或产品名称等关键字查询",
        "order_key": "(选填)排序字段,service_end=-1",
        }
    return send(methed="get", url="/authorization/list", params=params, headers=headers, files=files)


if __name__ == "__main__":
    # 签发授权
    post_authorization()
    # 详情
    get_authorization()
    # 编辑
    put_authorization()
    # 删除
    delete_authorization()
    # 授权列表
    get_authorization_list()
    